state

# XMLRésuméLibrary: User Guide

skillset | Element Reference | street

## Name

state — A name or abbreviation of a state

## Synopsis

### Content Model

    (#PCDATA)

### Attributes

Name | Type | Default
--- | --- | ---
id | ID | None
targets | CDATA | None

## Description

The `state` element contains the name or abbreviation for the name of a state or other similar political entity.

The `state` element represents a division of a country. It should not be confused with the `country` element, which represents a nation-state.

### Parents

`state` may be contained in these elements: `address`, `location`

### Attributes

`id`

  A string used to uniquely identify a state name. The name may then be referred to by this identifier.

## See Also

`province`, `county`, `prefecture`.

## Examples

Example 10. State name

    <state>New York</state>

Example 11. State abbreviation

    <state>NY</state>

skillset | Element Reference | street